==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/StackedSplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedSplineAreaSeriesDescription } from "./StackedSplineAreaSeriesDescription";
/**
 * @hidden
 */
export let StackedSplineAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedSplineAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StackedSplineAreaSeriesDescriptionMetadata.a == null) {
                StackedSplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedSplineAreaSeriesDescriptionMetadata.c(StackedSplineAreaSeriesDescriptionMetadata.a);
            }
            if (a.j(StackedSplineAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(StackedSplineAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
            a.item("IsSplineShapePartOfRange", "Boolean");
        }
        static d(a) {
            StackedSplineAreaSeriesDescriptionMetadata.b(a);
            a.aa("StackedSplineAreaSeries", () => new StackedSplineAreaSeriesDescription());
            a.z("StackedSplineAreaSeries", StackedSplineAreaSeriesDescriptionMetadata.a);
        }
    }
    StackedSplineAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(StackedSplineAreaSeriesDescriptionMetadata, 'StackedSplineAreaSeriesDescriptionMetadata');
    StackedSplineAreaSeriesDescriptionMetadata.a = null;
    return StackedSplineAreaSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/StackedSplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedSplineAreaSeriesDescription } from "./StackedSplineAreaSeriesDescription";
/**
 * @hidden
 */
export let StackedSplineAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedSplineAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StackedSplineAreaSeriesDescriptionMetadata.a == null) {
                StackedSplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedSplineAreaSeriesDescriptionMetadata.c(StackedSplineAreaSeriesDescriptionMetadata.a);
            }
            if (a.k(StackedSplineAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(StackedSplineAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
            a.item("IsSplineShapePartOfRange", "Boolean");
        }
        static d(a) {
            StackedSplineAreaSeriesDescriptionMetadata.b(a);
            a.ac("StackedSplineAreaSeries", () => new StackedSplineAreaSeriesDescription());
            a.ab("StackedSplineAreaSeries", StackedSplineAreaSeriesDescriptionMetadata.a);
        }
    }
    StackedSplineAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(StackedSplineAreaSeriesDescriptionMetadata, 'StackedSplineAreaSeriesDescriptionMetadata');
    StackedSplineAreaSeriesDescriptionMetadata.a = null;
    return StackedSplineAreaSeriesDescriptionMetadata;
})();
